@@ -49,10 +49,10 @@ double pearson(mine_problem *myprobl){
   return(r * r);
 }
 
-SEXP mineRonevar (SEXP x, SEXP y, SEXP alpha, SEXP C, SEXP EPS){
+SEXP mineRonevar (SEXP x, SEXP y, SEXP alpha, SEXP C, SEXP eps){
   
   double *restmp;
-  double eps;
+  double EPS;
   mine_problem *prob;
   mine_parameter *param;
   mine_score *minescore;
@@ -60,15 +60,13 @@ SEXP mineRonevar (SEXP x, SEXP y, SEXP alpha, SEXP C, SEXP EPS){
   
   PROTECT(alpha = coerceVector(alpha,REALSXP));
   PROTECT(C = coerceVector(C,INTSXP));
-  PROTECT(res=allocVector(REALSXP,6));
+  PROTECT(res=allocVector(REALSXP,5));
   restmp=REAL(res);
-  
+    
   param = (mine_parameter *) Calloc(1,mine_parameter);
   param->alpha=asReal(alpha);
   param->c=asReal(C);
   
-  eps = asReal(EPS);
-  
   prob = (mine_problem *) Calloc(1,mine_problem);
   prob->n=length(x);
   prob->x=REAL(x);
@@ -78,9 +76,14 @@ SEXP mineRonevar (SEXP x, SEXP y, SEXP alpha, SEXP C, SEXP EPS){
   restmp[0]=mine_mic(minescore);
   restmp[1]=mine_mas(minescore);
   restmp[2]=mine_mev(minescore);
-  restmp[3]=mine_mcn(minescore, eps);
-  restmp[4]=mine_mcn_general(minescore);
-  restmp[5]=restmp[0] - pearson(prob);
+  if (!isNull(eps)){
+    EPS=asReal(eps);
+    restmp[3]=mine_mcn(minescore,EPS);  
+  }else{
+    restmp[3]=mine_mcn_general(minescore);
+  }
+  
+  restmp[4]=restmp[0] - pearson(prob);
   
   /* Free */
   Free(prob);
@@ -90,22 +93,20 @@ SEXP mineRonevar (SEXP x, SEXP y, SEXP alpha, SEXP C, SEXP EPS){
   return(res);
 }
 
-SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP EPS)
+SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP eps)
 {
   R_len_t i, j, rx, cx;
-  double score, eps;
+  double score, EPS;
   double **pointers;
   mine_problem *prob;
   mine_parameter *param;
   mine_score *minescore;
-  SEXP res, mydim, resmic, resmas, resmev, resmcn, resmcng, resmicmr, names;
+  SEXP res, mydim, resmic, resmas, resmev, resmcn, resmicmr, names;
   
   param = (mine_parameter *) Calloc(1,mine_parameter);
   param->alpha=asReal(alpha);
   param->c=asReal(C);
   
-  eps = asReal(EPS);
-
   /* Matrix dimension */
   rx=asInteger(nrx);
   cx=asInteger(ncx);
@@ -124,17 +125,15 @@ SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP EPS)
   PROTECT(resmas=allocVector(REALSXP,cx*cx));
   PROTECT(resmev=allocVector(REALSXP,cx*cx));
   PROTECT(resmcn=allocVector(REALSXP,cx*cx));
-  PROTECT(resmcng=allocVector(REALSXP,cx*cx));
   PROTECT(resmicmr=allocVector(REALSXP,cx*cx));
-  PROTECT(res=allocVector(VECSXP,6));
+  PROTECT(res=allocVector(VECSXP,5));
   
   /* Allocating result list */
   SET_VECTOR_ELT(res, 0, resmic);
   SET_VECTOR_ELT(res, 1, resmas);
   SET_VECTOR_ELT(res, 2, resmev);
   SET_VECTOR_ELT(res, 3, resmcn);
-  SET_VECTOR_ELT(res, 4, resmcng);
-  SET_VECTOR_ELT(res, 5, resmicmr);
+  SET_VECTOR_ELT(res, 4, resmicmr);
   
   /* Set the mine_problem */
   prob = (mine_problem *) Calloc(1,mine_problem);
@@ -149,7 +148,7 @@ SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP EPS)
       score=mine_mic(minescore);
       REAL(resmic)[(cx*j) + i] = score;
       REAL(resmic)[(cx*i) + j] = score;
-      
+						
       score-=pearson(prob);
       REAL(resmicmr)[(cx*j) + i] = score;
       REAL(resmicmr)[(cx*i) + j] = score;
@@ -162,18 +161,15 @@ SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP EPS)
       REAL(resmev)[(cx*j) + i] = score;
       REAL(resmev)[(cx*i) + j] = score;
 
-      score=mine_mcn(minescore, eps);
+      if (!isNull(eps)){
+        EPS=asReal(eps);
+        score=mine_mcn(minescore,EPS);
+      }else{
+        score=mine_mcn_general(minescore);
+      }
       REAL(resmcn)[(cx*j) + i] = score;
       REAL(resmcn)[(cx*i) + j] = score;
-      
-      score=mine_mcn_general(minescore);
-      REAL(resmcng)[(cx*j) + i] = score;
-      REAL(resmcng)[(cx*i) + j] = score;
-      
-      /* score=mine_mcn(minescore, eps); */
-      /* REAL(resmcn)[(cx*j) + i] = score; */
-      /* REAL(resmcn)[(cx*i) + j] = score; */
-
+            
       /* Free score */
       mine_free_score(&minescore);
     }
@@ -188,20 +184,18 @@ SEXP mineRall (SEXP x, SEXP nrx, SEXP ncx, SEXP alpha, SEXP C, SEXP EPS)
   setAttrib(resmas, R_DimSymbol, mydim);
   setAttrib(resmev, R_DimSymbol, mydim);
   setAttrib(resmcn, R_DimSymbol, mydim);
-  setAttrib(resmcng, R_DimSymbol, mydim);
   setAttrib(resmicmr, R_DimSymbol, mydim);
   
-  PROTECT(names=allocVector(STRSXP,6));
+  PROTECT(names=allocVector(STRSXP,5));
   SET_STRING_ELT(names,0,mkChar("MIC"));
   SET_STRING_ELT(names,1,mkChar("MAS"));  
   SET_STRING_ELT(names,2,mkChar("MEV"));  
   SET_STRING_ELT(names,3,mkChar("MCN"));
-  SET_STRING_ELT(names,4,mkChar("MCN_GENERAL"));
-  SET_STRING_ELT(names,5,mkChar("MICR2"));
+  SET_STRING_ELT(names,4,mkChar("MICR2"));
   setAttrib(res, R_NamesSymbol,names);
   
   /* Free memeory */
-  UNPROTECT(10);
+  UNPROTECT(9);
   Free(pointers);
   Free(param);
   Free(prob);
